{% extends "announcements/base.html" %} {% load i18n %} {% load bootstrap_tags %} {% load url from future %} {% block body_class %}announcements{% endblock %} {% block body %}

# {% trans "Delete Announcement?" %}

{% url "announcements_delete" pk=announcement.pk as post_url %}

{% trans "Are you sure you want to delete this announcement?" %}

{{ announcement.title }}

{{ announcement.content }}

{% csrf_token %} {{ form|as_bootstrap }}
{% trans "Cancel" %}
{% endblock %}